@@ -224,6 +224,7 @@ class BaseExecutor:
 
         parameters = self.run_log_store.get_parameters(run_id=self.run_id)
         interaction.store_parameter(**parameters)
+        interaction.store_run_id()
 
         data_catalogs_get = self.sync_catalog(node, step_log, stage='get')
 
@@ -513,7 +514,7 @@ class BaseExecutor:
         effective_node_config = copy.deepcopy(self.config)
         ctx_node_config = node.get_mode_config(self.service_name)
 
-        placeholders = self.config.get('placeholders', None)
+        placeholders = self.config.get('placeholders', {})
 
         for key, value in ctx_node_config.items():
             if not value:
